@@ -10,7 +10,7 @@ from sympy.core.sympify import sympify
 from sympy.functions.elementary.piecewise import (piecewise_fold,
     Piecewise)
 from sympy.logic.boolalg import BooleanFunction
-from sympy.matrices.matrices import MatrixBase
+from sympy.matrices.matrixbase import MatrixBase
 from sympy.sets.sets import Interval, Set
 from sympy.sets.fancysets import Range
 from sympy.tensor.indexed import Idx
@@ -338,7 +338,7 @@ class ExprWithLimits(Expr):
             for i in xab[1:]:
                 isyms.update(i.free_symbols)
         reps = {v: k for k, v in reps.items()}
-        return set([reps.get(_, _) for _ in isyms])
+        return {reps.get(_, _) for _ in isyms}
 
     @property
     def is_number(self):
@@ -592,7 +592,9 @@ class AddWithLimits(ExprWithLimits):
 
     def _eval_expand_basic(self, **hints):
         summand = self.function.expand(**hints)
-        if summand.is_Add and summand.is_commutative:
+        force = hints.get('force', False)
+        if (summand.is_Add and (force or summand.is_commutative and
+                 self.has_finite_limits is not False)):
             return Add(*[self.func(i, *self.limits) for i in summand.args])
         elif isinstance(summand, MatrixBase):
             return summand.applyfunc(lambda x: self.func(x, *self.limits))
