@@ -1,11 +1,26 @@
 """Singleton mechanism"""
 
+from __future__ import annotations
+
+from typing import TYPE_CHECKING
 
 from .core import Registry
-from .assumptions import ManagedProperties
 from .sympify import sympify
 
 
+if TYPE_CHECKING:
+    from sympy.core.numbers import (
+        Zero as _Zero,
+        One as _One,
+        NegativeOne as _NegativeOne,
+        Half as _Half,
+        Infinity as _Infinity,
+        NegativeInfinity as _NegativeInfinity,
+        ComplexInfinity as _ComplexInfinity,
+        NaN as _NaN,
+    )
+
+
 class SingletonRegistry(Registry):
     """
     The registry for the singleton classes (accessible as ``S``).
@@ -41,7 +56,7 @@ class SingletonRegistry(Registry):
     True
 
     For the most part, the fact that certain objects are singletonized is an
-    implementation detail that users shouldn't need to worry about. In SymPy
+    implementation detail that users should not need to worry about. In SymPy
     library code, ``is`` comparison is often used for performance purposes
     The primary advantage of ``S`` for end users is the convenient access to
     certain instances that are otherwise difficult to type, like ``S.Half``
@@ -71,8 +86,7 @@ class SingletonRegistry(Registry):
     This is for convenience, since ``S`` is a single letter. It's mostly
     useful for defining rational numbers. Consider an expression like ``x +
     1/2``. If you enter this directly in Python, it will evaluate the ``1/2``
-    and give ``0.5`` (or just ``0`` in Python 2, because of integer division),
-    because both arguments are ints (see also
+    and give ``0.5``, because both arguments are ints (see also
     :ref:`tutorial-gotchas-final-notes`). However, in SymPy, you usually want
     the quotient of two integers to give an exact rational number. The way
     Python's evaluation works, at least one side of an operator needs to be a
@@ -85,6 +99,15 @@ class SingletonRegistry(Registry):
     """
     __slots__ = ()
 
+    Zero: _Zero
+    One: _One
+    NegativeOne: _NegativeOne
+    Half: _Half
+    Infinity: _Infinity
+    NegativeInfinity: _NegativeInfinity
+    ComplexInfinity: _ComplexInfinity
+    NaN: _NaN
+
     # Also allow things like S(5)
     __call__ = staticmethod(sympify)
 
@@ -132,7 +155,7 @@ class SingletonRegistry(Registry):
 S = SingletonRegistry()
 
 
-class Singleton(ManagedProperties):
+class Singleton(type):
     """
     Metaclass for singleton classes.
 
@@ -163,14 +186,8 @@ class Singleton(ManagedProperties):
     Instance creation is delayed until the first time the value is accessed.
     (SymPy versions before 1.0 would create the instance during class
     creation time, which would be prone to import cycles.)
-
-    This metaclass is a subclass of ManagedProperties because that is the
-    metaclass of many classes that need to be Singletons (Python does not allow
-    subclasses to have a different metaclass than the superclass, except the
-    subclass may use a subclassed metaclass).
     """
     def __init__(cls, *args, **kwargs):
-        super().__init__(cls, *args, **kwargs)
         cls._instance = obj = Basic.__new__(cls)
         cls.__new__ = lambda cls: obj
         cls.__getnewargs__ = lambda obj: ()
