@@ -1,53 +1,63 @@
-from sympy.integrals.transforms import (mellin_transform,
-    inverse_mellin_transform, laplace_transform, inverse_laplace_transform,
+from sympy.integrals.transforms import (
+    mellin_transform, inverse_mellin_transform,
     fourier_transform, inverse_fourier_transform,
     sine_transform, inverse_sine_transform,
     cosine_transform, inverse_cosine_transform,
     hankel_transform, inverse_hankel_transform,
-    LaplaceTransform, FourierTransform, SineTransform, CosineTransform,
-    InverseLaplaceTransform, InverseFourierTransform,
+    FourierTransform, SineTransform, CosineTransform, InverseFourierTransform,
     InverseSineTransform, InverseCosineTransform, IntegralTransformError)
-from sympy import (
-    gamma, exp, oo, Heaviside, symbols, Symbol, re, factorial, pi, arg,
-    cos, S, Abs, And, sin, sqrt, I, log, tan, hyperexpand, meijerg,
-    EulerGamma, erf, erfc, besselj, bessely, besseli, besselk,
-    exp_polar, unpolarify, Function, expint, expand_mul, Rational,
-    gammasimp, trigsimp, atan, sinh, cosh, Ne, periodic_argument, atan2)
-from sympy.utilities.pytest import XFAIL, slow, skip, raises
-from sympy.matrices import Matrix, eye
+from sympy.integrals.laplace import (
+    laplace_transform, inverse_laplace_transform)
+from sympy.core.function import Function, expand_mul
+from sympy.core import EulerGamma
+from sympy.core.numbers import I, Rational, oo, pi
+from sympy.core.singleton import S
+from sympy.core.symbol import Symbol, symbols
+from sympy.functions.combinatorial.factorials import factorial
+from sympy.functions.elementary.complexes import re, unpolarify
+from sympy.functions.elementary.exponential import exp, exp_polar, log
+from sympy.functions.elementary.miscellaneous import sqrt
+from sympy.functions.elementary.trigonometric import atan, cos, sin, tan
+from sympy.functions.special.bessel import besseli, besselj, besselk, bessely
+from sympy.functions.special.delta_functions import Heaviside
+from sympy.functions.special.error_functions import erf, expint
+from sympy.functions.special.gamma_functions import gamma
+from sympy.functions.special.hyper import meijerg
+from sympy.simplify.gammasimp import gammasimp
+from sympy.simplify.hyperexpand import hyperexpand
+from sympy.simplify.trigsimp import trigsimp
+from sympy.testing.pytest import XFAIL, slow, skip, raises
 from sympy.abc import x, s, a, b, c, d
+
+
 nu, beta, rho = symbols('nu beta rho')
 
 
 def test_undefined_function():
-    from sympy import Function, MellinTransform
+    from sympy.integrals.transforms import MellinTransform
     f = Function('f')
     assert mellin_transform(f(x), x, s) == MellinTransform(f(x), x, s)
     assert mellin_transform(f(x) + exp(-x), x, s) == \
-        (MellinTransform(f(x), x, s) + gamma(s), (0, oo), True)
-
-    assert laplace_transform(2*f(x), x, s) == 2*LaplaceTransform(f(x), x, s)
-    # TODO test derivative and other rules when implemented
+        (MellinTransform(f(x), x, s) + gamma(s + 1)/s, (0, oo), True)
 
 
 def test_free_symbols():
-    from sympy import Function
     f = Function('f')
     assert mellin_transform(f(x), x, s).free_symbols == {s}
     assert mellin_transform(f(x)*a, x, s).free_symbols == {s, a}
 
 
 def test_as_integral():
-    from sympy import Function, Integral
+    from sympy.integrals.integrals import Integral
     f = Function('f')
     assert mellin_transform(f(x), x, s).rewrite('Integral') == \
         Integral(x**(s - 1)*f(x), (x, 0, oo))
     assert fourier_transform(f(x), x, s).rewrite('Integral') == \
         Integral(f(x)*exp(-2*I*pi*s*x), (x, -oo, oo))
-    assert laplace_transform(f(x), x, s).rewrite('Integral') == \
+    assert laplace_transform(f(x), x, s, noconds=True).rewrite('Integral') == \
         Integral(f(x)*exp(-s*x), (x, 0, oo))
     assert str(2*pi*I*inverse_mellin_transform(f(s), s, x, (a, b)).rewrite('Integral')) \
-        == "Integral(x**(-s)*f(s), (s, _c - oo*I, _c + oo*I))"
+        == "Integral(f(s)/x**s, (s, _c - oo*I, _c + oo*I))"
     assert str(2*pi*I*inverse_laplace_transform(f(s), s, x).rewrite('Integral')) == \
         "Integral(f(s)*exp(s*x), (s, _c - oo*I, _c + oo*I))"
     assert inverse_fourier_transform(f(s), s, x).rewrite('Integral') == \
@@ -64,7 +74,7 @@ def test_mellin_transform_fail():
     MT = mellin_transform
 
     bpos = symbols('b', positive=True)
-    bneg = symbols('b', negative=True)
+    # bneg = symbols('b', negative=True)
 
     expr = (sqrt(x + b**2) + b)**a/sqrt(x + b**2)
     # TODO does not work with bneg, argument wrong. Needs changes to matching.
@@ -87,7 +97,7 @@ def test_mellin_transform_fail():
 
 
 def test_mellin_transform():
-    from sympy import Max, Min
+    from sympy.functions.elementary.miscellaneous import (Max, Min)
     MT = mellin_transform
 
     bpos = symbols('b', positive=True)
@@ -102,18 +112,15 @@ def test_mellin_transform():
         (gamma(beta)*gamma(s)/gamma(beta + s), (0, oo), re(beta) > 0)
     assert MT((x - 1)**(beta - 1)*Heaviside(x - 1), x, s) == \
         (gamma(beta)*gamma(1 - beta - s)/gamma(1 - s),
-            (-oo, -re(beta) + 1), re(beta) > 0)
+            (-oo, 1 - re(beta)), re(beta) > 0)
 
     assert MT((1 + x)**(-rho), x, s) == \
         (gamma(s)*gamma(rho - s)/gamma(rho), (0, re(rho)), True)
 
-    # TODO also the conditions should be simplified, e.g.
-    # And(re(rho) - 1 < 0, re(rho) < 1) should just be
-    # re(rho) < 1
     assert MT(abs(1 - x)**(-rho), x, s) == (
         2*sin(pi*rho/2)*gamma(1 - rho)*
-        cos(pi*(rho/2 - s))*gamma(s)*gamma(rho-s)/pi,
-        (0, re(rho)), And(re(rho) - 1 < 0, re(rho) < 1))
+        cos(pi*(s - rho/2))*gamma(s)*gamma(rho-s)/pi,
+        (0, re(rho)), re(rho) < 1)
     mt = MT((1 - x)**(beta - 1)*Heaviside(1 - x)
             + a*(x - 1)**(beta - 1)*Heaviside(x - 1), x, s)
     assert mt[1], mt[2] == ((0, -re(beta) + 1), re(beta) > 0)
@@ -122,12 +129,12 @@ def test_mellin_transform():
         pi*b**(a + s - 1)*sin(pi*a)/(sin(pi*s)*sin(pi*(a + s)))
     assert MT((x**a - bpos**a)/(x - bpos), x, s) == \
         (pi*bpos**(a + s - 1)*sin(pi*a)/(sin(pi*s)*sin(pi*(a + s))),
-            (Max(-re(a), 0), Min(1 - re(a), 1)), True)
+            (Max(0, -re(a)), Min(1, 1 - re(a))), True)
 
     expr = (sqrt(x + b**2) + b)**a
     assert MT(expr.subs(b, bpos), x, s) == \
         (-a*(2*bpos)**(a + 2*s)*gamma(s)*gamma(-a - 2*s)/gamma(-a - s + 1),
-         (0, -re(a)/2), True)
+            (0, -re(a)/2), True)
 
     expr = (sqrt(x + b**2) + b)**a/sqrt(x + b**2)
     assert MT(expr.subs(b, bpos), x, s) == \
@@ -152,7 +159,6 @@ def test_mellin_transform():
         (-gamma(s + S.Half)/(sqrt(pi)*s), (Rational(-1, 2), 0), True)
 
 
-@slow
 def test_mellin_transform2():
     MT = mellin_transform
     # TODO we cannot currently do these (needs summation of 3F2(-1))
@@ -171,7 +177,7 @@ def test_mellin_transform2():
 
 @slow
 def test_mellin_transform_bessel():
-    from sympy import Max
+    from sympy.functions.elementary.miscellaneous import Max
     MT = mellin_transform
 
     # 8.4.19
@@ -258,8 +264,8 @@ def test_mellin_transform_bessel():
     # TODO products of besselk are a mess
 
     mt = MT(exp(-x/2)*besselk(a, x/2), x, s)
-    mt0 = gammasimp((trigsimp(gammasimp(mt[0].expand(func=True)))))
-    assert mt0 == 2*pi**Rational(3, 2)*cos(pi*s)*gamma(-s + S.Half)/(
+    mt0 = gammasimp(trigsimp(gammasimp(mt[0].expand(func=True))))
+    assert mt0 == 2*pi**Rational(3, 2)*cos(pi*s)*gamma(S.Half - s)/(
         (cos(2*pi*a) - cos(2*pi*s))*gamma(-a - s + 1)*gamma(a - s + 1))
     assert mt[1:] == ((Max(-re(a), re(a)), oo), True)
     # TODO exp(x/2)*besselk(a, x/2) [etc] cannot currently be done
@@ -268,7 +274,10 @@ def test_mellin_transform_bessel():
 
 @slow
 def test_expint():
-    from sympy import E1, expint, Max, re, lerchphi, Symbol, simplify, Si, Ci, Ei
+    from sympy.functions.elementary.miscellaneous import Max
+    from sympy.functions.special.error_functions import Ci, E1, Si
+    from sympy.simplify.simplify import simplify
+
     aneg = Symbol('a', negative=True)
     u = Symbol('u', polar=True)
 
@@ -296,27 +305,14 @@ def test_expint():
         -4**s*sqrt(pi)*gamma(s)/(2*s*gamma(-s + S.Half)),
         s, u, (0, 1)).expand() == Ci(sqrt(u))
 
-    # TODO LT of Si, Shi, Chi is a mess ...
-    assert laplace_transform(Ci(x), x, s) == (-log(1 + s**2)/2/s, 0, True)
-    assert laplace_transform(expint(a, x), x, s) == \
-        (lerchphi(s*exp_polar(I*pi), 1, a), 0, re(a) > S.Zero)
-    assert laplace_transform(expint(1, x), x, s) == (log(s + 1)/s, 0, True)
-    assert laplace_transform(expint(2, x), x, s) == \
-        ((s - log(s + 1))/s**2, 0, True)
-
-    assert inverse_laplace_transform(-log(1 + s**2)/2/s, s, u).expand() == \
-        Heaviside(u)*Ci(u)
-    assert inverse_laplace_transform(log(s + 1)/s, s, x).rewrite(expint) == \
-        Heaviside(x)*E1(x)
-    assert inverse_laplace_transform((s - log(s + 1))/s**2, s,
-                x).rewrite(expint).expand() == \
-        (expint(2, x)*Heaviside(x)).rewrite(Ei).rewrite(expint).expand()
-
 
 @slow
 def test_inverse_mellin_transform():
-    from sympy import (sin, simplify, Max, Min, expand,
-                       powsimp, exp_polar, cos, cot)
+    from sympy.core.function import expand
+    from sympy.functions.elementary.miscellaneous import (Max, Min)
+    from sympy.functions.elementary.trigonometric import cot
+    from sympy.simplify.powsimp import powsimp
+    from sympy.simplify.simplify import simplify
     IMT = inverse_mellin_transform
 
     assert IMT(gamma(s), s, x, (0, oo)) == exp(-x)
@@ -360,10 +356,11 @@ def test_inverse_mellin_transform():
         == (x - 1)**(beta - 1)*Heaviside(x - 1)
     assert simp_pows(IMT(gamma(s)*gamma(rho - s)/gamma(rho), s, x, (0, None))) \
         == (1/(x + 1))**rho
-    assert simp_pows(IMT(d**c*d**(s - 1)*sin(pi*c)
+    expr = IMT(d**c*d**(s - 1)*sin(pi*c)
                          *gamma(s)*gamma(s + c)*gamma(1 - s)*gamma(1 - s - c)/pi,
-                         s, x, (Max(-re(c), 0), Min(1 - re(c), 1)))) \
-        == (x**c - d**c)/(x - d)
+                         s, x, (Max(-re(c), 0), Min(1 - re(c), 1)))
+    assert powsimp(expand_mul(expr, deep=False)).replace(exp_polar, exp).simplify() \
+        == (-d**c + x**c)/(-d + x)
 
     assert simplify(IMT(1/sqrt(pi)*(-c/2)*gamma(s)*gamma((1 - c)/2 - s)
                         *gamma(-c/2 - s)/gamma(1 - c - s),
@@ -371,8 +368,8 @@ def test_inverse_mellin_transform():
         (1 + sqrt(x + 1))**c
     assert simplify(IMT(2**(a + 2*s)*b**(a + 2*s - 1)*gamma(s)*gamma(1 - a - 2*s)
                         /gamma(1 - a - s), s, x, (0, (-re(a) + 1)/2))) == \
-        b**(a - 1)*(sqrt(1 + x/b**2) + 1)**(a - 1)*(b**2*sqrt(1 + x/b**2) +
-        b**2 + x)/(b**2 + x)
+        b**(a - 1)*(b**2*(sqrt(1 + x/b**2) + 1)**a + x*(sqrt(1 + x/b**2) + 1
+        )**(a - 1))/(b**2 + x)
     assert simplify(IMT(-2**(c + 2*s)*c*b**(c + 2*s)*gamma(s)*gamma(-c - 2*s)
                         / gamma(-c - s + 1), s, x, (0, -re(c)/2))) == \
         b**c*(sqrt(1 + x/b**2) + 1)**c
@@ -388,7 +385,9 @@ def test_inverse_mellin_transform():
 
     # TODO
     def mysimp(expr):
-        from sympy import expand, logcombine, powsimp
+        from sympy.core.function import expand
+        from sympy.simplify.powsimp import powsimp
+        from sympy.simplify.simplify import logcombine
         return expand(
             powsimp(logcombine(expr, force=True), force=True, deep=True),
             force=True).replace(exp_polar, exp)
@@ -449,175 +448,10 @@ def test_inverse_mellin_transform():
     assert IMT(pi/cos(pi*s), s, x, (0, S.Half)) == sqrt(x)/(x + 1)
 
 
-@slow
-def test_laplace_transform():
-    from sympy import fresnels, fresnelc
-    LT = laplace_transform
-    a, b, c, = symbols('a b c', positive=True)
-    t = symbols('t')
-    w = Symbol("w")
-    f = Function("f")
-
-    # Test unevaluated form
-    assert laplace_transform(f(t), t, w) == LaplaceTransform(f(t), t, w)
-    assert inverse_laplace_transform(
-        f(w), w, t, plane=0) == InverseLaplaceTransform(f(w), w, t, 0)
-
-    # test a bug
-    spos = symbols('s', positive=True)
-    assert LT(exp(t), t, spos)[:2] == (1/(spos - 1), 1)
-
-    # basic tests from wikipedia
-    assert LT((t - a)**b*exp(-c*(t - a))*Heaviside(t - a), t, s) == \
-        ((s + c)**(-b - 1)*exp(-a*s)*gamma(b + 1), -c, True)
-    assert LT(t**a, t, s) == (s**(-a - 1)*gamma(a + 1), 0, True)
-    assert LT(Heaviside(t), t, s) == (1/s, 0, True)
-    assert LT(Heaviside(t - a), t, s) == (exp(-a*s)/s, 0, True)
-    assert LT(1 - exp(-a*t), t, s) == (a/(s*(a + s)), 0, True)
-
-    assert LT((exp(2*t) - 1)*exp(-b - t)*Heaviside(t)/2, t, s, noconds=True) \
-        == exp(-b)/(s**2 - 1)
-
-    assert LT(exp(t), t, s)[:2] == (1/(s - 1), 1)
-    assert LT(exp(2*t), t, s)[:2] == (1/(s - 2), 2)
-    assert LT(exp(a*t), t, s)[:2] == (1/(s - a), a)
-
-    assert LT(log(t/a), t, s) == ((log(a*s) + EulerGamma)/s/-1, 0, True)
-
-    assert LT(erf(t), t, s) == (erfc(s/2)*exp(s**2/4)/s, 0, True)
-
-    assert LT(sin(a*t), t, s) == (a/(a**2 + s**2), 0, True)
-    assert LT(cos(a*t), t, s) == (s/(a**2 + s**2), 0, True)
-    # TODO would be nice to have these come out better
-    assert LT(exp(-a*t)*sin(b*t), t, s) == (b/(b**2 + (a + s)**2), -a, True)
-    assert LT(exp(-a*t)*cos(b*t), t, s) == \
-        ((a + s)/(b**2 + (a + s)**2), -a, True)
-
-    assert LT(besselj(0, t), t, s) == (1/sqrt(1 + s**2), 0, True)
-    assert LT(besselj(1, t), t, s) == (1 - 1/sqrt(1 + 1/s**2), 0, True)
-    # TODO general order works, but is a *mess*
-    # TODO besseli also works, but is an even greater mess
-
-    # test a bug in conditions processing
-    # TODO the auxiliary condition should be recognised/simplified
-    assert LT(exp(t)*cos(t), t, s)[:-1] in [
-        ((s - 1)/(s**2 - 2*s + 2), -oo),
-        ((s - 1)/((s - 1)**2 + 1), -oo),
-    ]
-
-    # Fresnel functions
-    assert laplace_transform(fresnels(t), t, s) == \
-        ((-sin(s**2/(2*pi))*fresnels(s/pi) + sin(s**2/(2*pi))/2 -
-            cos(s**2/(2*pi))*fresnelc(s/pi) + cos(s**2/(2*pi))/2)/s, 0, True)
-    assert laplace_transform(fresnelc(t), t, s) == (
-        ((2*sin(s**2/(2*pi))*fresnelc(s/pi) - 2*cos(s**2/(2*pi))*fresnels(s/pi)
-        + sqrt(2)*cos(s**2/(2*pi) + pi/4))/(2*s), 0, True))
-
-    cond = Ne(1/s, 1) & (
-        0 < cos(Abs(periodic_argument(s, oo)))*Abs(s) - 1)
-    assert LT(Matrix([[exp(t), t*exp(-t)], [t*exp(-t), exp(t)]]), t, s) ==\
-        Matrix([
-            [(1/(s - 1), 1, True), ((s + 1)**(-2), 0, True)],
-            [((s + 1)**(-2), 0, True), (1/(s - 1), 1, True)]
-        ])
-
-
-def test_issue_8368_7173():
-    LT = laplace_transform
-    # hyperbolic
-    assert LT(sinh(x), x, s) == (1/(s**2 - 1), 1, True)
-    assert LT(cosh(x), x, s) == (s/(s**2 - 1), 1, True)
-    assert LT(sinh(x + 3), x, s) == (
-        (-s + (s + 1)*exp(6) + 1)*exp(-3)/(s - 1)/(s + 1)/2, 1, True)
-    assert LT(sinh(x)*cosh(x), x, s) == (
-        1/(s**2 - 4), 2, Ne(s/2, 1))
-    # trig (make sure they are not being rewritten in terms of exp)
-    assert LT(cos(x + 3), x, s) == ((s*cos(3) - sin(3))/(s**2 + 1), 0, True)
-
-
-def test_inverse_laplace_transform():
-    from sympy import sinh, cosh, besselj, besseli, simplify, factor_terms
-    ILT = inverse_laplace_transform
-    a, b, c, = symbols('a b c', positive=True)
-    t = symbols('t')
-
-    def simp_hyp(expr):
-        return factor_terms(expand_mul(expr)).rewrite(sin)
-
-    # just test inverses of all of the above
-    assert ILT(1/s, s, t) == Heaviside(t)
-    assert ILT(1/s**2, s, t) == t*Heaviside(t)
-    assert ILT(1/s**5, s, t) == t**4*Heaviside(t)/24
-    assert ILT(exp(-a*s)/s, s, t) == Heaviside(t - a)
-    assert ILT(exp(-a*s)/(s + b), s, t) == exp(b*(a - t))*Heaviside(-a + t)
-    assert ILT(a/(s**2 + a**2), s, t) == sin(a*t)*Heaviside(t)
-    assert ILT(s/(s**2 + a**2), s, t) == cos(a*t)*Heaviside(t)
-    # TODO is there a way around simp_hyp?
-    assert simp_hyp(ILT(a/(s**2 - a**2), s, t)) == sinh(a*t)*Heaviside(t)
-    assert simp_hyp(ILT(s/(s**2 - a**2), s, t)) == cosh(a*t)*Heaviside(t)
-    assert ILT(a/((s + b)**2 + a**2), s, t) == exp(-b*t)*sin(a*t)*Heaviside(t)
-    assert ILT(
-        (s + b)/((s + b)**2 + a**2), s, t) == exp(-b*t)*cos(a*t)*Heaviside(t)
-    # TODO sinh/cosh shifted come out a mess. also delayed trig is a mess
-    # TODO should this simplify further?
-    assert ILT(exp(-a*s)/s**b, s, t) == \
-        (t - a)**(b - 1)*Heaviside(t - a)/gamma(b)
-
-    assert ILT(exp(-a*s)/sqrt(1 + s**2), s, t) == \
-        Heaviside(t - a)*besselj(0, a - t)  # note: besselj(0, x) is even
-
-    # XXX ILT turns these branch factor into trig functions ...
-    assert simplify(ILT(a**b*(s + sqrt(s**2 - a**2))**(-b)/sqrt(s**2 - a**2),
-                    s, t).rewrite(exp)) == \
-        Heaviside(t)*besseli(b, a*t)
-    assert ILT(a**b*(s + sqrt(s**2 + a**2))**(-b)/sqrt(s**2 + a**2),
-               s, t).rewrite(exp) == \
-        Heaviside(t)*besselj(b, a*t)
-
-    assert ILT(1/(s*sqrt(s + 1)), s, t) == Heaviside(t)*erf(sqrt(t))
-    # TODO can we make erf(t) work?
-
-    assert ILT(1/(s**2*(s**2 + 1)),s,t) == (t - sin(t))*Heaviside(t)
-
-    assert ILT( (s * eye(2) - Matrix([[1, 0], [0, 2]])).inv(), s, t) ==\
-        Matrix([[exp(t)*Heaviside(t), 0], [0, exp(2*t)*Heaviside(t)]])
-
-
-def test_inverse_laplace_transform_delta():
-    from sympy import DiracDelta
-    ILT = inverse_laplace_transform
-    t = symbols('t')
-    assert ILT(2, s, t) == 2*DiracDelta(t)
-    assert ILT(2*exp(3*s) - 5*exp(-7*s), s, t) == \
-        2*DiracDelta(t + 3) - 5*DiracDelta(t - 7)
-    a = cos(sin(7)/2)
-    assert ILT(a*exp(-3*s), s, t) == a*DiracDelta(t - 3)
-    assert ILT(exp(2*s), s, t) == DiracDelta(t + 2)
-    r = Symbol('r', real=True)
-    assert ILT(exp(r*s), s, t) == DiracDelta(t + r)
-
-
-def test_inverse_laplace_transform_delta_cond():
-    from sympy import DiracDelta, Eq, im, Heaviside
-    ILT = inverse_laplace_transform
-    t = symbols('t')
-    r = Symbol('r', real=True)
-    assert ILT(exp(r*s), s, t, noconds=False) == (DiracDelta(t + r), True)
-    z = Symbol('z')
-    assert ILT(exp(z*s), s, t, noconds=False) == \
-        (DiracDelta(t + z), Eq(im(z), 0))
-    # inversion does not exist: verify it doesn't evaluate to DiracDelta
-    for z in (Symbol('z', extended_real=False),
-              Symbol('z', imaginary=True, zero=False)):
-        f = ILT(exp(z*s), s, t, noconds=False)
-        f = f[0] if isinstance(f, tuple) else f
-        assert f.func != DiracDelta
-    # issue 15043
-    assert ILT(1/s + exp(r*s)/s, s, t, noconds=False) == (
-        Heaviside(t) + Heaviside(r + t), True)
-
 def test_fourier_transform():
-    from sympy import simplify, expand, expand_complex, factor, expand_trig
+    from sympy.core.function import (expand, expand_complex, expand_trig)
+    from sympy.polys.polytools import factor
+    from sympy.simplify.simplify import simplify
     FT = fourier_transform
     IFT = inverse_fourier_transform
 
@@ -673,8 +507,6 @@ def test_fourier_transform():
 
 
 def test_sine_transform():
-    from sympy import EulerGamma
-
     t = symbols("t")
     w = symbols("w")
     a = symbols("a")
@@ -701,7 +533,7 @@ def test_sine_transform():
         sqrt(2)*w/(sqrt(pi)*(a**2 + w**2)), w, t) == exp(-a*t)
 
     assert sine_transform(
-        log(t)/t, t, w) == -sqrt(2)*sqrt(pi)*(log(w**2) + 2*EulerGamma)/4
+        log(t)/t, t, w) == sqrt(2)*sqrt(pi)*-(log(w**2) + 2*EulerGamma)/4
 
     assert sine_transform(
         t*exp(-a*t**2), t, w) == sqrt(2)*w*exp(-w**2/(4*a))/(4*a**Rational(3, 2))
@@ -710,7 +542,7 @@ def test_sine_transform():
 
 
 def test_cosine_transform():
-    from sympy import Si, Ci
+    from sympy.functions.special.error_functions import (Ci, Si)
 
     t = symbols("t")
     w = symbols("w")
@@ -752,8 +584,6 @@ def test_cosine_transform():
 
 
 def test_hankel_transform():
-    from sympy import gamma, sqrt, exp
-
     r = Symbol("r")
     k = Symbol("k")
     nu = Symbol("nu")
@@ -802,42 +632,6 @@ def test_issue_8882():
         **{'as_meijerg': True, 'needeval': True}))
 
 
-def test_issue_7173():
-    from sympy import cse
-    x0, x1, x2, x3 = symbols('x:4')
-    ans = laplace_transform(sinh(a*x)*cosh(a*x), x, s)
-    r, e = cse(ans)
-    assert r == [
-        (x0, arg(a)),
-        (x1, Abs(x0)),
-        (x2, pi/2),
-        (x3, Abs(x0 + pi))]
-    assert e == [
-        a/(-4*a**2 + s**2),
-        0,
-        ((x1 <= x2) | (x1 < x2)) & ((x3 <= x2) | (x3 < x2))]
-
-
-def test_issue_8514():
-    from sympy import simplify
-    a, b, c, = symbols('a b c', positive=True)
-    t = symbols('t', positive=True)
-    ft = simplify(inverse_laplace_transform(1/(a*s**2+b*s+c),s, t))
-    assert ft == (I*exp(t*cos(atan2(0, -4*a*c + b**2)/2)*sqrt(Abs(4*a*c -
-                  b**2))/a)*sin(t*sin(atan2(0, -4*a*c + b**2)/2)*sqrt(Abs(
-                  4*a*c - b**2))/(2*a)) + exp(t*cos(atan2(0, -4*a*c + b**2)
-                  /2)*sqrt(Abs(4*a*c - b**2))/a)*cos(t*sin(atan2(0, -4*a*c
-                  + b**2)/2)*sqrt(Abs(4*a*c - b**2))/(2*a)) + I*sin(t*sin(
-                  atan2(0, -4*a*c + b**2)/2)*sqrt(Abs(4*a*c - b**2))/(2*a))
-                  - cos(t*sin(atan2(0, -4*a*c + b**2)/2)*sqrt(Abs(4*a*c -
-                  b**2))/(2*a)))*exp(-t*(b + cos(atan2(0, -4*a*c + b**2)/2)
-                  *sqrt(Abs(4*a*c - b**2)))/(2*a))/sqrt(-4*a*c + b**2)
 def test_issue_12591():
     x, y = symbols("x y", real=True)
     assert fourier_transform(exp(x), x, y) == FourierTransform(exp(x), x, y)
-
-
-def test_issue_14692():
-    b = Symbol('b', negative=True)
-    assert laplace_transform(1/(I*x - b), x, s) == \
-        (-I*exp(I*b*s)*expint(1, b*s*exp_polar(I*pi/2)), 0, True)
