@@ -8,12 +8,22 @@ TODO:
 * Doctests and documentation of special methods for InnerProduct, Commutator,
   AntiCommutator, represent, apply_operators.
 """
+from typing import Optional
 
-from sympy import Derivative, Expr, Integer, oo, Mul, expand, Add
+from sympy.core.add import Add
+from sympy.core.expr import Expr
+from sympy.core.function import (Derivative, expand)
+from sympy.core.mul import Mul
+from sympy.core.numbers import oo
+from sympy.core.singleton import S
 from sympy.printing.pretty.stringpict import prettyForm
 from sympy.physics.quantum.dagger import Dagger
+from sympy.physics.quantum.kind import OperatorKind
 from sympy.physics.quantum.qexpr import QExpr, dispatch_method
 from sympy.matrices import eye
+from sympy.utilities.exceptions import sympy_deprecation_warning
+
+
 
 __all__ = [
     'Operator',
@@ -67,7 +77,7 @@ class Operator(QExpr):
         >>> C
         2*A**2 + I*B
 
-    Operators don't commute::
+    Operators do not commute::
 
         >>> A.is_commutative
         False
@@ -95,11 +105,14 @@ class Operator(QExpr):
     .. [1] https://en.wikipedia.org/wiki/Operator_%28physics%29
     .. [2] https://en.wikipedia.org/wiki/Observable
     """
-
+    is_hermitian: Optional[bool] = None
+    is_unitary: Optional[bool] = None
     @classmethod
     def default_args(self):
         return ("O",)
 
+    kind = OperatorKind
+
     #-------------------------------------------------------------------------
     # Printing
     #-------------------------------------------------------------------------
@@ -163,6 +176,9 @@ class Operator(QExpr):
     def _apply_operator(self, ket, **options):
         return dispatch_method(self, '_apply_operator', ket, **options)
 
+    def _apply_from_right_to(self, bra, **options):
+        return None
+
     def matrix_element(self, *args):
         raise NotImplementedError('matrix_elements is not defined')
 
@@ -174,13 +190,6 @@ class Operator(QExpr):
     def _eval_inverse(self):
         return self**(-1)
 
-    def __mul__(self, other):
-
-        if isinstance(other, IdentityOperator):
-            return self
-
-        return Mul(self, other)
-
 
 class HermitianOperator(Operator):
     """A Hermitian operator that satisfies H == Dagger(H).
@@ -211,14 +220,14 @@ class HermitianOperator(Operator):
 
     def _eval_power(self, exp):
         if isinstance(self, UnitaryOperator):
-            if exp == -1:
-                return Operator._eval_power(self, exp)
-            elif abs(exp) % 2 == 0:
-                return self*(Operator._eval_inverse(self))
-            else:
+            # so all eigenvalues of self are 1 or -1
+            if exp.is_even:
+                from sympy.core.singleton import S
+                return S.One # is identity, see Issue 24153.
+            elif exp.is_odd:
                 return self
-        else:
-            return Operator._eval_power(self, exp)
+        # No simplification in all other cases
+        return Operator._eval_power(self, exp)
 
 
 class UnitaryOperator(Operator):
@@ -239,7 +248,7 @@ class UnitaryOperator(Operator):
     >>> U*Dagger(U)
     1
     """
-
+    is_unitary = True
     def _eval_adjoint(self):
         return self._eval_inverse()
 
@@ -248,6 +257,10 @@ class IdentityOperator(Operator):
     """An identity operator I that satisfies op * I == I * op == op for any
     operator op.
 
+    .. deprecated:: 1.14.
+        Use the scalar S.One instead as the multiplicative identity for
+        operators and states.
+
     Parameters
     ==========
 
@@ -259,9 +272,11 @@ class IdentityOperator(Operator):
     ========
 
     >>> from sympy.physics.quantum import IdentityOperator
-    >>> IdentityOperator()
+    >>> IdentityOperator() # doctest: +SKIP
     I
     """
+    is_hermitian = True
+    is_unitary = True
     @property
     def dimension(self):
         return self.N
@@ -271,13 +286,21 @@ class IdentityOperator(Operator):
         return (oo,)
 
     def __init__(self, *args, **hints):
-        if not len(args) in [0, 1]:
+        sympy_deprecation_warning(
+            """
+            IdentityOperator has been deprecated. In the future, please use
+            S.One as the identity for quantum operators and states.
+            """,
+            deprecated_since_version="1.14",
+            active_deprecations_target='deprecated-operator-identity',
+        )
+        if not len(args) in (0, 1):
             raise ValueError('0 or 1 parameters expected, got %s' % args)
 
         self.N = args[0] if (len(args) == 1 and args[0]) else oo
 
     def _eval_commutator(self, other, **hints):
-        return Integer(0)
+        return S.Zero
 
     def _eval_anticommutator(self, other, **hints):
         return 2 * other
@@ -291,6 +314,9 @@ class IdentityOperator(Operator):
     def _apply_operator(self, ket, **options):
         return ket
 
+    def _apply_from_right_to(self, bra, **options):
+        return bra
+
     def _eval_power(self, exp):
         return self
 
@@ -303,13 +329,6 @@ class IdentityOperator(Operator):
     def _print_contents_latex(self, printer, *args):
         return r'{\mathcal{I}}'
 
-    def __mul__(self, other):
-
-        if isinstance(other, (Operator, Dagger)):
-            return other
-
-        return Mul(self, other)
-
     def _represent_default_basis(self, **options):
         if not self.N or self.N == oo:
             raise NotImplementedError('Cannot represent infinite dimensional' +
@@ -344,7 +363,6 @@ class OuterProduct(Operator):
     Create a simple outer product by hand and take its dagger::
 
         >>> from sympy.physics.quantum import Ket, Bra, OuterProduct, Dagger
-        >>> from sympy.physics.quantum import Operator
 
         >>> k = Ket('k')
         >>> b = Bra('b')
@@ -360,24 +378,17 @@ class OuterProduct(Operator):
         >>> Dagger(op)
         |b><k|
 
-    In simple products of kets and bras outer products will be automatically
+    In quantum expressions, outer products will be automatically
     identified and created::
 
         >>> k*b
         |k><b|
 
-    But in more complex expressions, outer products are not automatically
-    created::
+    However, the creation of inner products always has higher priority than that of
+    outer products:
 
-        >>> A = Operator('A')
-        >>> A*k*b
-        A*|k>*<b|
-
-    A user can force the creation of an outer product in a complex expression
-    by using parentheses to group the ket and bra::
-
-        >>> A*(k*b)
-        A*|k><b|
+        >>> b*k*b
+        <b|k>*<b|
 
     References
     ==========
@@ -607,7 +618,7 @@ class DifferentialOperator(Operator):
 
         return self.expr.free_symbols
 
-    def _apply_operator_Wavefunction(self, func):
+    def _apply_operator_Wavefunction(self, func, **options):
         from sympy.physics.quantum.state import Wavefunction
         var = self.variables
         wf_vars = func.args[1:]
