@@ -21,12 +21,13 @@ convenience methods, for example if there are faster algorithms available.
 from copy import copy
 from functools import reduce
 
-from sympy.core.compatibility import iterable
 from sympy.polys.agca.ideals import Ideal
 from sympy.polys.domains.field import Field
 from sympy.polys.orderings import ProductOrder, monomial_key
+from sympy.polys.polyclasses import DMP
 from sympy.polys.polyerrors import CoercionFailed
 from sympy.core.basic import _aresame
+from sympy.utilities.iterables import iterable
 
 # TODO
 # - module saturation
@@ -269,8 +270,11 @@ class FreeModuleElement(ModuleElement):
         return tuple(x / p for x in d)
 
     def __repr__(self):
-        from sympy import sstr
-        return '[' + ', '.join(sstr(x) for x in self.data) + ']'
+        from sympy.printing.str import sstr
+        data = self.data
+        if any(isinstance(x, DMP) for x in data):
+            data = [self.module.ring.to_sympy(x) for x in data]
+        return '[' + ', '.join(sstr(x) for x in data) + ']'
 
     def __iter__(self):
         return self.data.__iter__()
@@ -700,7 +704,7 @@ class SubModule(Module):
         generators of ``self`` (``rela``) and ``other`` (``relb``).
 
         >>> F.submodule([x, x]).intersect(F.submodule([y, y]), relations=True)
-        (<[x*y, x*y]>, [(y,)], [(x,)])
+        (<[x*y, x*y]>, [(DMP_Python([[1, 0]], QQ),)], [(DMP_Python([[1], []], QQ),)])
 
         The above result says: the intersection module is generated by the
         single element `(-xy, -xy) = -y (x, x) = -x (y, y)`, where
@@ -741,7 +745,7 @@ class SubModule(Module):
         generators of ``self``.
 
         >>> S.module_quotient(T, relations=True)
-        (<y>, [[1]])
+        (<y>, [[DMP_Python([[1]], QQ)]])
 
         This means that the quotient ideal is generated by the single element
         `y`, and that `y (x, x) = 1 (xy, xy)`, `(x, x)` and `(xy, xy)` being
@@ -895,8 +899,8 @@ class SubModule(Module):
         >>> from sympy import QQ
         >>> F = QQ.old_poly_ring(x).free_module(2)
         >>> M = F.submodule([1, 0], [1, 1])
-        >>> M.in_terms_of_generators([x, x**2])
-        [-x**2 + x, x**2]
+        >>> M.in_terms_of_generators([x, x**2])  # doctest: +SKIP
+        [DMP_Python([-1, 1, 0], QQ), DMP_Python([1, 0, 0], QQ)]
         """
         try:
             e = self.convert(e)
@@ -1153,7 +1157,8 @@ class SubModulePolyRing(SubModule):
     def _groebner_vec(self, extended=False):
         """Returns a standard basis in element form."""
         if not extended:
-            return [self.convert(self.ring._sdm_to_vector(x, self.rank))
+            return [FreeModuleElement(self,
+                        tuple(self.ring._sdm_to_vector(x, self.rank)))
                     for x in self._groebner()]
         gb, gbe = self._groebner(extended=True)
         return ([self.convert(self.ring._sdm_to_vector(x, self.rank))
@@ -1170,21 +1175,22 @@ class SubModulePolyRing(SubModule):
         """Compute syzygies. See [SCA, algorithm 2.5.4]."""
         # NOTE if self.gens is a standard basis, this can be done more
         #      efficiently using Schreyer's theorem
-        from sympy.matrices import eye
 
         # First bullet point
         k = len(self.gens)
         r = self.rank
-        im = eye(k)
+        zero = self.ring.convert(0)
+        one = self.ring.convert(1)
         Rkr = self.ring.free_module(r + k)
         newgens = []
         for j, f in enumerate(self.gens):
             m = [0]*(r + k)
             for i, v in enumerate(f):
-                m[i] = f[i]
+                m[i] = v
             for i in range(k):
-                m[r + i] = im[j, i]
-            newgens.append(Rkr.convert(m))
+                m[r + i] = one if j == i else zero
+            m = FreeModuleElement(Rkr, tuple(m))
+            newgens.append(m)
         # Note: we need *descending* order on module index, and TOP=False to
         #       get an elimination order
         F = Rkr.submodule(*newgens, order='ilex', TOP=False)
@@ -1193,8 +1199,7 @@ class SubModulePolyRing(SubModule):
         G = F._groebner_vec()
 
         # Third bullet point: G0 = G intersect the new k components
-        G0 = [x[r:] for x in G if all(y == self.ring.convert(0)
-                                      for y in x[:r])]
+        G0 = [x[r:] for x in G if all(y == zero for y in x[:r])]
 
         # Fourth and fifth bullet points: we are done
         return G0
